#!/bin/sh
#---------------------------------------------------------------------------- 
# /tmp/preinstall.sh  - hddtemp preinstallation script
#
# Creation:     2005-11-30 Stephan Sanders
# Last Update:  2023-11-05 Marcus Roeckrath
#
# Copyright (c) 2005-2013 Stephan Sanders
#               2019-2023 Marcus Roeckrath, marcus.roeckrath(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

package_name=hddtemp

# ---------------------------------------------------------------------------
# Remove old style menu file from release < 0.1.6
# ---------------------------------------------------------------------------
installed=$(eisman check ${package_name} 0.1.6)
if [ "${installed}" = "new" ]
then
    rm -f /var/install/bin/setup.services.${package_name}
fi

# ---------------------------------------------------------------------------
# Remove faulty deinstall script and filelist from release < 1.0.0
# ---------------------------------------------------------------------------
installed=$(eisman check ${package_name} 1.0.0)
if [ "${installed}" = "new" ]
then
    rm -f /var/install/deinstall/${package_name}
    rm -f /etc/filelist.d/${package_name}-files.txt
    rm -f /usr/local/bin/${package_name}
fi

# ---------------------------------------------------------------------------
# Remove /usr/share/misc/hddtemp because it now resides in /etc
# ---------------------------------------------------------------------------
installed=$(eisman check ${package_name} 3.4.0)
if [ "${installed}" = "new" ]
then
    rm -rf /usr/share/misc/${package_name}.db
fi

# ---------------------------------------------------------------------------
# Switch from SysVInit to Systemd
# ---------------------------------------------------------------------------
# Exit if not installed
installed=$(eisman check ${package_name})
if [ "${installed}" = "not_installed" ]
then
     exit 0
fi

# Switch from SysVInit to Systemd
if /usr/bin/grep -q '/etc/init\.d' /var/install/deinstall/${package_name}
then
     /usr/sbin/service --quiet stop ${package_name}
     /usr/sbin/service disable ${package_name}
fi

exit 0
# ---------------------------------------------------------------------------
# End
# ---------------------------------------------------------------------------
