#!/bin/sh
# ---------------------------------------------------------------------------
# /var/install/config.d/hddtemp-update.sh - parameter update script
#
# Creation   :  2019-04-10 Marcus Roeckrath, marcus.roeckrath(at)gmx(dot)de
# Last Update:  2019-04-11 Marcus Roeckrath
#
# Copyright (c) 2019 Marcus Roeckrath, marcus.roeckrath(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ---------------------------------------------------------------------------

# set package name
package_name=hddtemp

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

#exec 2> /tmp/hddtemp-update-trace$$.log
#set -x

VERSION=$( sed -n '/<version>/ s# ##g; s#</*version>##gp' \
           /var/install/packages/${package_name} )

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_HDDTEMP='no'

HDDTEMP_OPTIONS='-w'
HDDTEMP_DEVICES='/dev/hda /dev/sda'

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        # backup old configfile
        /var/install/bin/backup-file --quiet ${package_name}

        . /etc/config.d/${package_name}
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
        # -----------------------------------------------------------------------
        printgpl --conf ${package_name} "2019-04-11" "Marcus Roeckrath"
        # -----------------------------------------------------------------------
        echo "# hddtemp-VERSION ${VERSION}"
        #------------------------------------------------------------------------
        printgroup 'hddtemp configuration'
        #------------------------------------------------------------------------

        printvar 'START_HDDTEMP' 'Activate hddtemp at boot in daemon mode? Use: yes or no'

        #-------------------------------------------------------------------------
        printgroup 'Settings for hddtemp'
        #-------------------------------------------------------------------------

        printvar 'HDDTEMP_OPTIONS' 'See hddtemp --help; -w wakeup when hd sleeping'

        printvar 'HDDTEMP_DEVICES' 'Devices for hddtemp'

        # ------------------------------------------------------------------------
        printend
        # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
#----------------------------------------------------------------------------
printgpl --check ${package_name} '2019-04-10' 'Marcus Roeckrath' >/etc/check.d/${package_name}
#----------------------------------------------------------------------------
cat >> /etc/check.d/${package_name} <<EOF
# Variable               OPT_VARIABLE                  VARIABLE_N            VALUE
START_HDDTEMP            -                             -                     YESNO

HDDTEMP_OPTIONS          START_HDDTEMP                 -                     NONE
HDDTEMP_DEVICES          START_HDDTEMP                 -                     NOTEMPTY
EOF

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${package_name}
    chown root /etc/check.d/${package_name}
}
# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------

make_config_file /etc/default.d/${package_name}

# Update from old version
rename_old_variables

# Write new config file
make_config_file /etc/config.d/${package_name}

# Write check.d file
make_check_file

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
