#!/bin/sh
# ---------------------------------------------------------------------------
# /var/install/config.d/hddtemp.sh - hddtemp configuration
#
# Creation   :  2019-04-10 Marcus Roeckrath, marcus(dot)roeckrath(at)gmx(dot)de
# Last Update:  2023-11-05 Marcus Roeckrath
#
# Copyright (c) 2019-2023 Marcus Roeckrath, marcus(dot)roeckrath(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ---------------------------------------------------------------------------

# Package name
package_name=hddtemp

. /var/install/include/eislib

#debug=true

if ${debug:-false}
then
    exec 2>/tmp/$(basename ${0})-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

VERSION=$(sed -n '/<version>/ s# ##g; s#</*version>##gp' \
          /var/install/packages/${package_name})

. /etc/config.d/${package_name}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------

/usr/sbin/service stop ${package_name}

# Write hddtemp sysconfig file
cat > /etc/sysconfig/${package_name} <<EOF
# -------------------------------------------------------------------------
# ${package_name} sysconfig file
#
# Do not edit this file, use configuration entry in ${package_name} services menu.
#
# Creation Date: ${EISDATE} Time: ${EISTIME}
# -------------------------------------------------------------------------
# Program name
HDDTEMP_NAME="${package_name}"

# hddtemp database of supported devices
HDDTEMP_OPTIONS="${HDDTEMP_OPTIONS}"

# Put at least the disk(s) you want to monitor here.
HDDTEMP_DEVICES="${HDDTEMP_DEVICES}"
EOF

if [ "${START_HDDTEMP}" = "yes" ]
then
    /usr/sbin/service enable ${package_name}
    /usr/sbin/service start ${package_name}
else
    /usr/sbin/service disable ${package_name}
fi

exit 0
# ---------------------------------------------------------------------------
# End
# ---------------------------------------------------------------------------
